@@ -304,7 +304,13 @@ class AppFromFileAttribute(AppAttribute):
         def _get_objects_fn(_self):
             cache_name = '_%s_cache' % name
             if not hasattr(_self, cache_name):
-                setattr(_self, cache_name, self.klass.all_from_file(_self.get_cache_file(name), _self.get_locale()))
+                app_attributes = self.klass.all_from_file(_self.get_cache_file(name), _self.get_locale())
+                if name == "settings":
+                    custom_settings_file = os.path.join(DATA_DIR, _self.id, 'custom.settings')
+                    if os.path.isfile(custom_settings_file):
+                        app_logger.debug("custom settings {} file found".format(custom_settings_file))
+                        app_attributes += self.klass.all_from_file(custom_settings_file, _self.get_locale())
+                setattr(_self, cache_name, app_attributes)
             return getattr(_self, cache_name)
 
         setattr(klass, 'get_%s' % name, _get_objects_fn)
