@@ -3,7 +3,8 @@ ONLINE_BASE = 'repository/online'
 COMPONENT_BASE = '%s/component' % ONLINE_BASE
 
 # Parameter names for component definitions
-COMP_PARAMS = ['description', 'server', 'prefix', 'password', 'username', 'defaultpackages', 'version', 'localmirror', 'unmaintained']
+COMP_PARAMS = ['description', 'server', 'prefix', 'password', 'username', 'defaultpackages', 'version', 'localmirror', 'unmaintained', 'port']
+DEPRECATED_PARAMS = ['prefix', 'username', 'password', 'port']
 
 # Symbolic error codes for UCR write operations
 PUT_SUCCESS = 0
@@ -14,9 +15,9 @@ PUT_UPDATER_ERROR = 4  # after saving options, any errors related to repositorie
 PUT_UPDATER_NOREPOS = 5  # nothing committed, but not found any valid repository
 
 STATUS_ICONS = {
-	'installed': 'updater-installed',
-	'available': 'updater-available',
-	'access_denied': 'updater-access-denied'
+    'installed': 'updater-installed',
+    'available': 'updater-available',
+    'access_denied': 'updater-access-denied',
 }
 DEFAULT_ICON = 'updater-unknown'  # any states not defined above
 
